@@ -17,7 +17,7 @@
 
 import os
 
-from reahl.web.fw import Region
+from reahl.web.fw import UserInterface
 
-web.site_root = Region
+web.site_root = UserInterface
 web.static_root = os.getcwd()
